@@ -127,7 +127,9 @@ keymap is `isearch-mode-map'.")
 (put 'image-scroll-up 'isearch-scroll t)
 (put 'image-scroll-down 'isearch-scroll t)
 
-(define-minor-mode pdf-isearch-active-mode "" nil nil nil
+(define-minor-mode pdf-isearch-active-mode
+  "This mode is enabled when isearch is active in a PDF file."
+  :group 'pdf-isearch
   (cond
    (pdf-isearch-active-mode
     (set (make-local-variable 'isearch-mode-map)
@@ -218,7 +220,6 @@ If this mode is enabled, isearching does not stop at every match,
 but rather moves to the next one not currently visible.  This
 behaviour is much faster than ordinary isearch, since far less
 different images have to be displayed."
-  nil nil nil
   :group 'pdf-isearch
   (when isearch-mode
     (pdf-isearch-redisplay)
@@ -742,7 +743,7 @@ MATCH-BG LAZY-FG LAZY-BG\)."
                                  occur-hack-p)
                              (eq page (pdf-view-current-page)))
                     (pdf-view-display-image
-                     (pdf-view-create-image data))))))))
+                     (pdf-view-create-image data :width width))))))))
       (pdf-info-renderpage-text-regions
        page width t nil
        `(,fg1 ,bg1 ,@(pdf-util-scale-pixel-to-relative
